Documentation
¶
Overview ¶
Package log is a convenience wrapper for logging messages of various levels
Index ¶
Constants ¶
This section is empty.
Variables ¶
var DefaultLogger = &Logger{debug: false}
DefaultLogger is the default logging implementation. It's used in all top level funcs inside the log package, and represents the equivalent of NewLogger(os.Stderr, os.Stderr)
Functions ¶
func Debug ¶
func Debug(msg string, v ...interface{})
Debug is a convenience function for DefaultLogger.Debug(...)
func Err ¶
func Err(format string, v ...interface{})
Err is a convenience function for DefaultLogger.Err(...)
func Info ¶
func Info(format string, v ...interface{})
Info is a convenience function for DefaultLogger.Info(...)
func Reinitialize ¶
func Reinitialize()
Reinitialize reads LOKI_CLIENT_PUSH_URL and sets up the loki client
Types ¶
type Logger ¶
type Logger struct {
// contains filtered or unexported fields
}
Logger is the base logging struct from which all logging functionality stems
func NewLogger ¶
NewLogger creates a new logger bound to a stdout and stderr writer, which are most commonly os.Stdout and os.Stderr, respectively